@@ -21,11 +21,14 @@ def add_methods(resource, s, auth=None):
 
 class Resource(object):
 
-    def __init__(self, url, data=None, schema=None, auth=None):
+    def __init__(self, url, data=None, schema=None,
+                 auth=None, response=None, timeout=30):
         self.auth = auth
         self.url = url
         self.data = data
         self.schema = schema
+        self.timeout = timeout
+        self.response = response
         if self.schema:
             if self.is_valid():
                 add_methods(self, self.schema, self.auth)
@@ -73,7 +76,7 @@ class Resource(object):
                     self.data[key] = data_items
 
 
-def get(url, auth=None):
+def get(url, auth=None, timeout=30):
     headers = {
         'content-type': 'application/json'
     }
@@ -81,7 +84,7 @@ def get(url, auth=None):
         headers['Authorization'] = '{0} {1}'.format(
             auth['type'], auth['credentials']
         )
-    response = requests.get(url, headers=headers)
+    response = requests.get(url, headers=headers, timeout=timeout)
     return from_response(response, auth)
 
 
@@ -94,5 +97,6 @@ def from_response(response, auth=None):
         url=response.url,
         auth=auth,
         data=data,
-        schema=schema.from_header(response.headers, auth)
+        schema=schema.from_header(response.headers, auth),
+        response=response
     )
